@@ -26,4 +26,6 @@ pub struct ProtectionInfo {
     pub expiry: String,
     #[serde(default)]
     pub cascade: bool,
+    /// Source the cascade protection is coming from
+    pub source: Option<String>,
 }
